@@ -39,6 +39,6 @@ def add_info(report, ui):
     if directory:
         arch = report['Architecture']
         commands['BootEFIContents'] = 'ls %s' % efiboot
-        commands['ShimDiff'] = 'diff %s/shim%s.efi /usr/lib/shim/shim.efi.signed' % (efiboot, efiarch[arch])
+        commands['ShimDiff'] = 'diff %s/shim%s.efi /usr/lib/shim/shim%s.efi.signed' % (efiboot, efiarch[arch], efiarch[arch])
         commands['GrubDiff'] = 'diff %s/grub%s.efi /usr/lib/grub/%s-efi-signed/grub%s.efi.signed' %(efiboot, efiarch[arch], grubarch[arch], efiarch[arch])
         attach_root_command_outputs(report, commands)
